@@ -65,11 +65,13 @@ class AsyncSessionTestCase(unittest.TestCase):
             ioc.provide(self.ioc_session_factory_key,
                 self.get_session, force=True)
 
-    def tearDown(self):
+    def tearDown(self, close_loop=True):
         for name, tx in dict.items(self.transactions):
             self.run_sync(tx.rollback)
         for ctx in dict.values(self.sessions):
             self.run_sync(ctx.__aexit__, None, None, None)
+        if close_loop:
+            self.loop.close()
 
     def execute_query(self, session, q, name='self'):
         """Execute query `q` and return the awaited result."""
