@@ -20,8 +20,10 @@ class TestAsyncSessionTestCase(AsyncSessionTestCase):
         super().setUp()
 
     def tearDown(self):
-        super().tearDown()
-        
-        session = async_session()
-        result = self.execute_query(session, select(Foo))
-        self.assertEqual(len(list(result)), 0)
+        super().tearDown(close_loop=False)
+        try:
+            session = async_session()
+            result = self.execute_query(session, select(Foo))
+            self.assertEqual(len(list(result)), 0)
+        finally:
+            self.loop.close()
